M = Manifold(2, 'M')
X = M.chart('x y'); x, y = X[:]
v = M.vector_field(-y, x, name='v')
g = v.plot()
sphinx_plot(g)